@@ -8,6 +8,7 @@
 #library(GenSA)
 #library(data.table)
 #dyn.load("misse-ext-derivs.so")
+#dyn.load("birthdeath-ext-derivs.so")
 
 ######################################################################################################################################
 ######################################################################################################################################
@@ -34,6 +35,17 @@ MiSSE <- function(phy, f=1, turnover=c(1,2), eps=c(1,2), condition.on.survival=T
         stop("Check that you specified a proper root.type option. Options are 'madfitz' or 'herr_als'. See help for more details.", call.=FALSE)
     }
 
+    if(length(turnover) != length(eps)){
+        stop("The number of turnover parameters need to match the number of extinction fraction parameters.", call.=FALSE)
+    }
+
+
+    ntips <- Ntip(phy)
+    param.count <- sum(c(length(unique(turnover)), length(unique(eps)), 1))
+    if(param.count > (ntips/10)){
+        warning("You might not have enough data to fit this model well", call.=FALSE, immediate.=TRUE)
+    }
+
     pars <- numeric(53)
     rate.cats <- hidden.states <- length(turnover)
     turnover.tmp <- numeric(26)
@@ -43,11 +55,14 @@ MiSSE <- function(phy, f=1, turnover=c(1,2), eps=c(1,2), condition.on.survival=T
     eps.tmp[1:length(eps)] <- eps
     eps.tmp[which(eps.tmp > 0)] = (eps.tmp[which( eps.tmp > 0)] + max(pars.tmp))
     pars.tmp <- c(pars.tmp, eps.tmp)
-    trans.tmp <- 1
-    trans.tmp <- trans.tmp + max(pars.tmp)
+    if(rate.cats > 1){
+        trans.tmp <- 1
+        trans.tmp <- trans.tmp + max(pars.tmp)
+    }else{
+        trans.tmp <- 0
+    }
     pars.tmp <- c(turnover.tmp[1], eps.tmp[1], turnover.tmp[2], eps.tmp[2], turnover.tmp[3], eps.tmp[3], turnover.tmp[4], eps.tmp[4], turnover.tmp[5], eps.tmp[5], turnover.tmp[6], eps.tmp[6], turnover.tmp[7], eps.tmp[7], turnover.tmp[8], eps.tmp[8], turnover.tmp[9], eps.tmp[9], turnover.tmp[10], eps.tmp[10], turnover.tmp[11], eps.tmp[11], turnover.tmp[12], eps.tmp[12], turnover.tmp[13], eps.tmp[13], turnover.tmp[14], eps.tmp[14], turnover.tmp[15], eps.tmp[15], turnover.tmp[16], eps.tmp[16], turnover.tmp[17], eps.tmp[17], turnover.tmp[18], eps.tmp[18], turnover.tmp[19], eps.tmp[19], turnover.tmp[20], eps.tmp[20], turnover.tmp[21], eps.tmp[21], turnover.tmp[22], eps.tmp[22], turnover.tmp[23], eps.tmp[23], turnover.tmp[24], eps.tmp[24], turnover.tmp[25], eps.tmp[25], turnover.tmp[26], eps.tmp[26], trans.tmp[1])
     pars[1:length(pars.tmp)] <- pars.tmp
-    
     np <- max(pars)
     pars[pars==0] <- np + 1
 
@@ -77,7 +92,7 @@ MiSSE <- function(phy, f=1, turnover=c(1,2), eps=c(1,2), condition.on.survival=T
 
         if(is.null(starting.vals)){
             def.set.pars <- rep(c(log(init.pars[1]+init.pars[2]), log(init.pars[2]/init.pars[1])), rate.cats)
-            trans.start <- log(0.01)
+            trans.start <- log(rate.cats/sum(phy$edge.length))
         }else{
             def.set.pars <- rep(c(log(starting.vals[1]), log(starting.vals[2])), rate.cats)
             trans.start <- log(starting.vals[3])
@@ -88,15 +103,24 @@ MiSSE <- function(phy, f=1, turnover=c(1,2), eps=c(1,2), condition.on.survival=T
             upper.full <- rep(21, length(def.set.pars))
         }
 
-        np.sequence <- 1:(np-1)
-        ip <- numeric(np-1)
-        upper <- numeric(np-1)
+        if(rate.cats > 1){
+            np.sequence <- 1:(np-1)
+            ip <- numeric(np-1)
+            upper <- numeric(np-1)
+        }else{
+            np.sequence <- 1:np
+            ip <- numeric(np)
+            upper <- numeric(np)
+        }
+        
         for(i in np.sequence){
             ip[i] <- def.set.pars[which(pars == np.sequence[i])[1]]
             upper[i] <- upper.full[which(pars == np.sequence[i])[1]]
         }
-        ip <- c(ip, trans.start)
-        upper <- c(upper, trans.upper)
+        if(rate.cats > 1){
+            ip <- c(ip, trans.start)
+            upper <- c(upper, log(trans.upper))
+        }
         lower <- rep(-20, length(ip))
     }else{
         upper <- restart.obj$upper.bounds
@@ -165,7 +189,6 @@ DevOptimizeMiSSE <- function(p, pars, dat.tab, gen, hidden.states, nb.tip=nb.tip
     model.vec[] <- c(p.new, 0)[pars]
     cache <- ParametersToPassMiSSE(model.vec=model.vec, hidden.states=hidden.states, nb.tip=nb.tip, nb.node=nb.node, bad.likelihood=exp(-500), ode.eps=ode.eps)
     logl <- DownPassMisse(dat.tab=dat.tab, cache=cache, gen=gen, condition.on.survival=condition.on.survival, root.type=root.type, root.p=root.p)
-
     return(-logl)
 }
 
@@ -177,28 +200,6 @@ DevOptimizeMiSSE <- function(p, pars, dat.tab, gen, hidden.states, nb.tip=nb.tip
 ######################################################################################################################################
 ######################################################################################################################################
 
-FindGenerations <- function(phy){
-    generation <- list()
-    known <- 1:Ntip(phy)
-    unknown <- phy$edge[,1]
-    needed <- phy$edge[,2]
-    root <- min(unknown)
-    i <- 1
-    repeat{
-        knowable <- unknown[needed %in% known]
-        knowable <- knowable[duplicated(knowable)]
-        generation[[i]] <-  knowable
-        
-        known <- c(known, knowable)
-        needed <- needed[!unknown %in% knowable]
-        unknown <- unknown[!unknown %in% knowable]
-        i <- i + 1
-        if (any(root == knowable)) break
-    }
-    res <- generation
-    return(res)
-}
-
 
 OrganizeDataMiSSE <- function(phy, f, hidden.states){
     ### Ughy McUgherson. This is a must in order to pass CRAN checks: http://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when
@@ -206,12 +207,9 @@ OrganizeDataMiSSE <- function(phy, f, hidden.states){
     
     nb.tip <- length(phy$tip.label)
     nb.node <- phy$Nnode
-    
+
     compD <- matrix(0, nrow=nb.tip, ncol=26)
-    compD[,1:hidden.states] = 1
     compE <- matrix(0, nrow=nb.tip, ncol=26)
-    compE[,1:hidden.states] = 1
-    
     #Initializes the tip sampling and sets internal nodes to be zero:
     ncols = hidden.states
     if(length(f) == 1){
@@ -247,8 +245,10 @@ SingleChildProbMiSSE <- function(cache, compD, compE, start.time, end.time, x){
     pars <- c(cache$lambda0A, cache$mu0A, cache$lambda0B, cache$mu0B, cache$lambda0C, cache$mu0C, cache$lambda0D, cache$mu0D, cache$lambda0E, cache$mu0E, cache$lambda0F, cache$mu0F, cache$lambda0G, cache$mu0G, cache$lambda0H, cache$mu0H, cache$lambda0I, cache$mu0I, cache$lambda0J, cache$mu0J, cache$lambda0K, cache$mu0K, cache$lambda0L, cache$mu0L, cache$lambda0M, cache$mu0M, cache$lambda0N, cache$mu0N, cache$lambda0O, cache$mu0O, cache$lambda0P, cache$mu0P, cache$lambda0Q, cache$mu0Q, cache$lambda0R, cache$mu0R, cache$lambda0S, cache$mu0S, cache$lambda0T, cache$mu0T, cache$lambda0U, cache$mu0U, cache$lambda0V, cache$mu0V, cache$lambda0W, cache$mu0W, cache$lambda0X, cache$mu0X, cache$lambda0Y, cache$mu0Y, cache$lambda0Z, cache$mu0Z, cache$q0, cache$hidden.states)
     yini <- c(E0A = compE[1], E0B = compE[2], E0C = compE[3], E0D = compE[4], E0E = compE[5], E0F = compE[6], E0G = compE[7], E0H = compE[8], E0I = compE[9], E0J = compE[10], E0K = compE[11], E0L = compE[12], E0M = compE[13], E0N = compE[14], E0O = compE[15], E0P = compE[16], E0Q = compE[17], E0R = compE[18], E0S = compE[19], E0T = compE[20], E0U = compE[21], E0V = compE[22], E0W = compE[23], E0X = compE[24], E0Y = compE[25], E0Z = compE[26], D0A = compD[1], D0B = compD[2], D0C = compD[3], D0D = compD[4], D0E = compD[5], D0F = compD[6], D0G = compD[7], D0H = compD[8], D0I = compD[9], D0J = compD[10], D0K = compD[11], D0L = compD[12], D0M = compD[13], D0N = compD[14], D0O = compD[15], D0P = compD[16], D0Q = compD[17], D0R = compD[18], D0S = compD[19], D0T = compD[20], D0U = compD[21], D0V = compD[22], D0W = compD[23], D0X = compD[24], D0Y = compD[25], D0Z = compD[26])
     times=c(start.time, end.time)
+    
     #prob.subtree.cal.full <- lsoda(yini, times, func = "misse_derivs", pars, initfunc="initmod_misse", dll = "misse-ext-derivs", rtol=1e-8, atol=1e-8)
     prob.subtree.cal.full <- lsoda(yini, times, func = "misse_derivs", pars, initfunc="initmod_misse", dllname = "hisse", rtol=1e-8, atol=1e-8)
+    
     ######## THIS CHECKS TO ENSURE THAT THE INTEGRATION WAS SUCCESSFUL ###########
     if(attributes(prob.subtree.cal.full)$istate[1] < 0){
         prob.subtree.cal <- prob.subtree.cal.full[-1,-1]
@@ -274,7 +274,7 @@ SingleChildProbMiSSE <- function(cache, compD, compE, start.time, end.time, x){
         prob.subtree.cal[27:52] <- cache$bad.likelihood
         return(prob.subtree.cal)
     }
-
+    
     return(prob.subtree.cal)
 }
 
@@ -338,7 +338,7 @@ GetRootProbMiSSE <- function(cache, dat.tab, generations){
 
 ######################################################################################################################################
 ######################################################################################################################################
-### The MuHiSSE type down pass that carries out the integration and returns the likelihood:
+### The MiSSE type down pass that carries out the integration and returns the likelihood:
 ######################################################################################################################################
 ######################################################################################################################################
 
@@ -560,7 +560,7 @@ print.misse.fit <- function(x,...){
     ntips <- Ntip( x$phy )
     nstates <- x$hidden.states
     output <- c(x$loglik, x$AIC, x$AICc, ntips, nstates)
-    names(output) <- c("-lnL", "AIC", "AICc", "n.taxa", "n.hidden.states")
+    names(output) <- c("lnL", "AIC", "AICc", "n.taxa", "n.hidden.states")
     cat("\n")
     cat("Fit \n")
     print(output)
@@ -573,15 +573,25 @@ print.misse.fit <- function(x,...){
 
 
 
+
+#phy <- read.tree("../vignettes/whales_Steemanetal2009.tre")
 #phy <- read.tree("whales_Slateretal2010.tre")
 ## print(p.new)
-#gen <- FindGenerations(phy)
-#dat.tab <- OrganizeDataMiSSE(phy=phy, f=1, hidden.states=2)
+#gen <- hisse:::FindGenerations(phy)
+#dat.tab <- hisse:::OrganizeDataMiSSE(phy=phy, f=1, hidden.states=1)
 #nb.tip <- Ntip(phy)
 #nb.node <- phy$Nnode
-#model.vec <- c(0.1344463, 0.150996, 0.1344463, 0.150996, rep(0,48), 1)
-#cache = ParametersToPassMiSSE(model.vec=model.vec, hidden.states=2, nb.tip=nb.tip, nb.node=nb.node, bad.likelihood=exp(-500), ode.eps=0)
-#logl <- DownPassMisse(dat.tab=dat.tab, cache=cache, gen=gen, condition.on.survival=TRUE, root.type="madfitz", root.p=root.p)
+#model.vec <- c(0.103624, 5.207178e-09, rep(0,52), 1)
+
+#cache = hisse:::ParametersToPassMiSSE(model.vec=model.vec, hidden.states=1, nb.tip=nb.tip, nb.node=nb.node, bad.likelihood=exp(-500), ode.eps=0)#
+#logl <- hisse:::DownPassMisse(dat.tab=dat.tab, cache=cache, gen=gen, condition.on.survival=TRUE, root.type="madfitz", root.p=NULL)
+#right.logl <- -277.6942
+#round(logl,4) == round(right.logl,4)
+
+
+
+
+
 
 
 
